# VCF filter

Prepping Raw VCF

```bash

#Total Variants (without Outgroup)
gunzip Puffin_MT_SnpsAndIndels.raw.vcf.gz
module purge
module load VCFtools/0.1.16-intel-2018b-Perl-5.28.0
module load BCFtools/1.9-intel-2018b
vcftools --vcf Puffin_MT_SnpsAndIndels.raw.vcf --remove-indels --out Puffin_MT_SnpsAndIndels.raw

```

Analysis of Puffin VCF

```bash
# filtering
bcftools filter --SnpGap 10 -e 'QD < 2.0 || MQ < 40 || FS > 60.0 || SOR > 3 || MQRankSum < -12.5 || ReadPosRankSum < -8.0' -o MT_SnpsAndIndels.filtered1.vcf Puffin_MT_SnpsAndIndels.raw.vcf
# More filtering on Depth and genotypeQuality
bcftools filter -S . -e 'FMT/DP<3 | FMT/GQ<15' -o _MT_SnpsAndIndels.filtered2.vcf MT_SnpsAndIndels.filtered1.vcf
# Filtering on monomorphic SNPs and remove indels - only keep biallelic
bcftools filter -e 'AC==0 || AC==AN' MT_SnpsAndIndels.filtered2.vcf | bcftools view -m2 -M2 -v snps -o MT_Snps.filtered1.vcf
bcftools view -H MT_Snps.filtered1.vcf | wc -l

cp _MT_Snps.filtered1.vcf _MT_Snps.filtered2.vcf

#Remove IOM001 and redo stats
vcftools --vcf MT_Snps.filtered2.vcf --remove-indv IOM001 --recode --recode-INFO-all --out MT_Snps.filtered3.vcf
# use vcflib vcffixup to correct AC, AF and NS 
vcffixup MT_Snps.filtered3.vcf.recode.vcf > MT_Snps.filtered3.edit.vcf

# Exclude monomorphic SNPs from Puffins again
bcftools filter -e 'AC==0 || AC==AN' MT_Snps.filtered3.edit.vcf | bcftools view -m2 -M2 -v snps -o MT_Snps.filtered4.vcf
bcftools view -H MT_Snps.filtered4.vcf | wc -l

# remove sites with missing data
vcftools --vcf MT_Snps.filtered4.vcf --max-missing 1.0 --recode --recode-INFO-all --out_MT_Snps.filtered5.vcf
grep -v "#" MT_Snps.filtered5.vcf.recode.vcf | wc -l

# Final
cp _MT_Snps.filtered5.vcf.recode.vcf PuffinMT_noOut_SNPs.filtered.vcf

bgzip -c -i PuffinMT_noOut_SNPs.filtered.vcf > PuffinMT_noOut_SNPs.filtered.vcf.gz
bcftools index PuffinMT_noOut_SNPs.filtered.vcf.gz

cat samples.list | grep -v "RAZ" - | grep -v "THU" - | grep -v "IOM001" - | while read line ;
do sample=$(echo ${line} | awk -F '.' '{print $1}') ;
echo ${sample} ;
bcftools consensus -s ${sample} -H 1 -M N -f Assembly_Puffin_mitogenome.final.fasta PuffinMT_noOut_SNPs.filtered.vcf.gz > ${sample}.CompleteMitoRef.SNPs.fasta ;
done ;
touch CompleteMitoRef.SNPs.AllPuffin.fasta
cat samples.list | grep -v "RAZ" - | grep -v "THU" - | grep -v "IOM001" - | while read line ;
do sample=$(echo ${line} | awk -F '.' '{print $1}') ;
cat ${sample}.CompleteMitoRef.SNPs.fasta | grep -v "^>" - | awk -v VAR=${sample} 'BEGIN { ORS=""; print ">"VAR"\n" } { print $0"\n"}' >> CompleteMitoRef.SNPs.AllPuffin.fasta ;
done
rm *.CompleteMitoRef.SNPs.fasta

```