# Quality Check 


Remove mitochondrial sequence from bam

```bash

cat ../Modern.samples | grep -v "THU" - | grep -v "RAZ" - | while read i ;
do sbatch BamToNU_bam.sh ${i} ; done

```

nano BamToNU_bam.sh

```bash
#!/bin/bash

module load SAMtools/1.9-GCC-8.2.0-2.31.1

samtools index ${1}.Assembly_Puffin_NUMT.realigned.bam
samtools view -@ 8 -b -h -o ${1}.Assembly_Puffin_NU.bam ${1}.Assembly_Puffin_NUMT.realigned.bam Scaffolds_chromosome_10 Scaffolds_chromosome_11 Scaffolds_chromosome_12 Scaffolds_chromosome_13 Scaffolds_chromosome_14 Scaffolds_chromosome_15 Scaffolds_chromosome_16 Scaffolds_chromosome_17 Scaffolds_chromosome_18 Scaffolds_chromosome_19 Scaffolds_chromosome_1 Scaffolds_chromosome_20 Scaffolds_chromosome_21 Scaffolds_chromosome_22 Scaffolds_chromosome_23 Scaffolds_chromosome_24 Scaffolds_chromosome_25 Scaffolds_chromosome_2 Scaffolds_chromosome_3 Scaffolds_chromosome_4 Scaffolds_chromosome_5 Scaffolds_chromosome_6 Scaffolds_chromosome_7 Scaffolds_chromosome_8 Scaffolds_chromosome_9 Scaffolds_chromosome_Z Scaffolds_unplaced
samtools sort -@ 8 ${1}.Assembly_Puffin_NU.bam > ${1}.Assembly_Puffin_NU.sorted.bam
samtools index ${1}.Assembly_Puffin_NU.sorted.bam
rm ${1}.Assembly_Puffin_NU.bam
rm ${1}.Assembly_Puffin_NUMT.realigned.bam
rm ${1}.Assembly_Puffin_NUMT.realigned.bam.bai
```

ANGSD - QualityCheck (based on chr. 1)

```bash
# listing files for ANGSD to work on:
ls *.bam > bams

sbatch Puffin_ANGSD_QC.sh
```

-> Puffin_ANGSD_QC.sh

```bash
#!/bin/bash

FILTERS="-uniqueOnly 1 -remove_bads 1 -minMapQ 25 -maxDepth 800 -checkBamHeaders 1 -C 50 -baq 2 "

TODO="-doQsDist 1 -doDepth 1 -doCounts 1 -dumpCounts 2"

module load angsd/0.931-GCC-8.2.0-2.31.1

Threads="12"

angsd -b bams -GL 1 $FILTERS $TODO -P ${Threads} -ref Assembly_Puffin_NU.MT.fasta -r Scaffolds_chromosome_1: -out PuffQC

```

R to produce QC1 pdf

```
gunzip PuffQC.counts.gz # 1 min
#subsample counts for every 10th SNP starting after header (reducing file size so R can handle - should be about 20M SNPs)
head -1 PuffQC.counts > PuffQC.header
awk 'NR % 10 == 2' PuffQC.counts > PuffQC.counts2  #takes an hour
cat PuffQC.header PuffQC.counts2 > PuffQC.counts3
wc -l PuffQC.counts3 #used for Rscript, insert as no. of rows for last graph - read.table - 21369188 #for RAM purpose, close all other apps
#edit and run plotQC.R # using cannibalized Matteo Fumagalli's script
Rscript ./plotQC.R PuffQC > qranks #warning messages are fine #need to adjust the number of individuals/columns and n's for last graph
#takes 10 min for 20M (limited by RAM though)
rm PuffQC.counts2
rm PuffQC.counts3
gzip PuffQC.counts #takes also an hour

# percentages of sites with coverage >5x in each sample, from worst to best:
cat qranks
# look at PuffQC.pdf for more details
```

2nd round of quality check

```
# use nano to manually remove poorly covered sample(s) from bams - IOM001 removed

sbatch Puffin_ANGSD_QC2.sh
```

-> Puffin_ANGSD_QC2.sh

```bash
#!/bin/bash

FILTERS="-uniqueOnly 1 -remove_bads 1 -minMapQ 25 -maxDepth 800 -checkBamHeaders 1 -C 50 -baq 2 "

TODO="-doQsDist 1 -doDepth 1 -doCounts 1 -dumpCounts 2"

module load angsd/0.931-GCC-8.2.0-2.31.1

Threads="12"

angsd -b bams_good -GL 1 $FILTERS $TODO -P ${Threads} -ref Assembly_Puffin_NU.MT.fasta -r Scaffolds_chromosome_1: -out PuffQC2

```

R to produce QC2 pdf

```
gunzip PuffQC2.counts.gz # 1 min
#subsample counts for every 10th SNP starting after header (reducing file size so R can handle - should be about 20M SNPs)
head -1 PuffQC2.counts > PuffQC2.header
awk 'NR % 10 == 2' PuffQC2.counts > PuffQC2.counts2  #takes an hour
cat PuffQC2.header PuffQC2.counts2 > PuffQC2.counts3
wc -l PuffQC2.counts3 #used for Rscript, insert as no. of rows for last graph - read.table - 21369159 #for RAM purpose, close all other apps
#edit and run plotQC.R # using cannibalized Matteo Fumagalli's script
Rscript ./plotQC.R PuffQC2 > qranks2 #warning messages are fine #need to adjust the number of individuals/columns and n's for last graph
#takes 10 min for 20M (limited by RAM though)
rm PuffQC2.counts2
rm PuffQC2.counts3

# percentages of sites with coverage >5x in each sample, from worst to best:
cat qranks2
# look at PuffQC2.pdf for more details
```