# EEMS

First make matrix (avg. distance between pairs of individuals) in ANGSD
Then use matrix as input for EEMS


```bash
zcat ModernPuffinAngsd_NoZ_NoUnpl.beagle.ldpruned.gz | tail -n+2 | cut -f 1 | awk -F '_' '{print $1"_"$2"_"$3"\t"$4}' > sites2do
wc -l sites2do

awk '{print $1":"}' sites2do | sort | uniq > sites2do.rf

sbatch Puffin_ANGSD_EEMS.sh

```

-> Puffin_ANGSD_EEMS.sh

```bash
#!/bin/bash

FILTERS="-uniqueOnly 1 -remove_bads 1 -minMapQ 30 -minQ 30 -C 50 -baq 2 -checkBamHeaders 1 -doHWE 1 -skipTriallelic 1 -minInd 71"
TODO="-doMajorMinor 1 -doMaf 1 -doCounts 1 -makeMatrix 1 -doIBS 2"

module load angsd/0.931-GCC-8.2.0-2.31.1

sleep 120 #to make sure the index files are newer

angsd sites index sites2do

sleep 120

angsd -b bams_good -GL 1 $FILTERS $TODO -ref Assembly_Puffin_NU.MT.fasta -rf sites2do.rf -sites sites2do -out ModernPuffinAngsd_IBS

```

EEMS

```bash
mv ModernPuffinAngsd_IBS.ibsMat Puffin.diffs

# Insert sample coordinates (long lat) into ColonyCoordinates.txt
# then

touch Puffin.coord
cat bams_good | awk -F '.' '{print $1}' | while read sample ;
do echo ${sample} ;
pop=$(echo ${sample} | awk -F '0' '{print $1}') ;
echo ${pop} ;
cat ColonyCoordinates.txt | grep -w ${pop} | awk '{print $2" "$1}' >> Puffin.coord ;
done

# Habitat Outline (long lat) / counter clockwise
# use online tool, then save in Polygon.txt

cp Polygon.txt Puffin.outer

# edit params-chain.ini to include wanted parameters

for N in $(seq 1 10) ;
do echo ${N};
cp params-chain.ini params-chain${N}.ini
sbatch EEMS.sh ${N} ;
done

```

-> EEMS.sh

```bash
#!/bin/bash

R1=$(echo $RANDOM % 100 | bc)
R2=$(echo $RANDOM % 100 | bc)
S=$(bc <<<"scale=0; ${R1} * ${R2} * ${1}")

runeems_snps --params params-chain${1}.ini --mcmcpath Puffin_EEMS_output_chain${1} --seed ${S} > EEMS_Puffin_chain${1}.log

```

Plotting in R

```bash
library(rEEMSplots)
library(rgdal)
library(rworldmap) 
library(rworldxtra)


eems_results <- grep("Puffin_EEMS_output_chain", list.dirs(path = ".", full.names = TRUE, recursive = TRUE), value = TRUE)
name_figures <- file.path("Puffin_EEMS_plot_results/Combined")

projection_none <- "+proj=longlat +datum=WGS84"
projection_mercator <- "+proj=merc +datum=WGS84"


eems.plots(mcmcpath = eems_results, 
           plotpath = name_figures, 
           longlat = TRUE, 
           out.png = TRUE, res = 800,
           plot.height = 8, plot.width = 7,
           add.outline = TRUE, col.outline = "blue", lwd.outline = 1.5,  
           add.demes = TRUE, col.demes = "red", min.cex.demes = 1.5, max.cex.demes = 1.8, 
           projection.in = projection_none,
           projection.out = projection_mercator,
           add.map = TRUE, col.map = "black", lwd.map = 1,
           add.abline = TRUE, add.r.squared = TRUE
           )

```