# Admixture


```bash

# NgsAdmix for K from 1 to 10
for K in $(seq 1 10) ;
do echo ${K};
for i in $(seq 1 50) ;
do sbatch NgsAdmix.sh ${K} ${i};
done ;
done ;


```

-> NgsAdmix.sh

```bash
#!/bin/bash

#making a random seed
R=$(echo $RANDOM % 100 | bc)
S=$(bc <<<"scale=0; ${R} * ${1} * ${2}")

#ngsAdmix
module load NGSadmix/32-GCC-7.3.0-2.30

Threads=16

NGSadmix -likes ModernPuffinAngsd_NoZ_NoUnpl.beagle.ldpruned.gz -K ${1} -P ${Threads} -o ModernPuffinAngsd_NoZ_NoUnpl.beagle.ldpruned_ngsAdmix_k${1}_n${2} -maxiter 5000 -seed ${S}

```

CLUMPAK

```bash
#Zip file for Clumpak run
for i in 1 2 3 4 5 6 7 8 9 10 ;
do zip K${i}_ModernPuffinAngsd_NoZ_NoUnpl.zip ModernPuffinAngsd_NoZ_NoUnpl.beagle.ldpruned_ngsAdmix_k${i}_*.qopt ;
done ;
zip ModernPuffinAngsd_AllK_NoZ_NoUnpl.zip K*_ModernPuffinAngsd_NoZ_NoUnpl.zip

#use NgsAdmix2Clumpak.R
logs <- as.data.frame(read.table("logfile"))
logs$K <- c(rep("10", 50), rep("2", 20), rep("3", 20),
rep("4", 20), rep("5", 20), rep("6", 20), rep("7", 20), rep("8", 20), rep("9", 20))
write.table(logs[, c(2, 1)], "logfile_formatted.txt", row.names = F,
col.names = F, quote = F)

#sort file
sort -n -k1,1 logfile_formatted.txt | awk -F ' ' '{print $1"\t"$2}' > logfile_formatted_clumpak.txt

#then clumpak ; http://clumpak.tau.ac.il/bestK.html
# with logfile and zip file
# save output zipfolders as EvannoOut and ClumpakOut

#check best K's (Evanno) and select mean Qmatrix file based Clumpakk

awk '{print $6"\t"$7}' Clumpak/K=2/MajorCluster/CLUMPP.files/ClumppIndFile.output > K2_Clumpak_MajorQmatrix.txt
awk '{print $6"\t"$7"\t"$8}' Clumpak/K=3/MajorCluster/CLUMPP.files/ClumppIndFile.output > K3_Clumpak_MajorQmatrix.txt
awk '{print $6"\t"$7"\t"$8"\t"$9}' Clumpak/K=4/MajorCluster/CLUMPP.files/ClumppIndFile.output > K4_Clumpak_MajorQmatrix.txt

```

Plotting in R example

```bash
library(ggplot2)
library(ggrepel)
library(RcppCNPy)
library(reshape2)
library(gridExtra)
library(ggpubr)

bams=read.table("bams_good")[,1] # list of bam files
bams=sub(".Assembly_Puffin_NU.sorted.bam","",bams) #gets rid of unneccessary parts of filenames
colonies=substr(bams, 1, 3)


colorcodesk2=c("#a6611a", "#018571")
colorcodesk3=c("#a6611a", "#018571", "#dfc27d")
colorcodesk4=c("#a6611a", "#018571", "#dfc27d", "#80cdc1")


#########################
#### ARRANGE IN GRID #### 
#########################

p2 <- ggplot(data=K2_mat_melt, aes(y = K2_mat_melt$value, x = K2_mat_melt$Sample, fill = K2_mat_melt$variable, facets = K2_mat_melt$Colony)) + 
  geom_bar(position="fill", stat="identity", colour=NA, size=0, width = 1) +
  scale_x_discrete(breaks = NULL, labels = NULL) +
  scale_y_continuous(limits = c(0,1), expand = c(0, 0), sec.axis = dup_axis()) +
  facet_grid(.~Colony, space="free_x", scales="free_x", switch="x") + 
  theme_bw() +
  theme(panel.background = element_blank(),panel.grid.major = element_blank(),
        panel.grid.minor = element_blank(), panel.border = element_rect(color = "black", size = 0.5),
        panel.spacing.x = unit(0.15, "lines"),
        axis.text.x=element_blank(),
        axis.text.y.left =element_text(colour="black"),
        axis.title.y.left =element_blank(),
        axis.line = element_line(colour = "black"),
        plot.title = element_text(hjust = 0.5, size=16, face="bold"), 
        axis.title.x = element_blank(),
        axis.text.y.right =element_blank(),
        axis.title.y.right = element_text(size=12, face="bold", angle = 0, vjust = 0.5),
        axis.ticks.y.right =element_blank(),
        legend.position = "none",
        strip.placement = "outside", strip.background = element_rect(fill=NA,colour=NA), panel.spacing=unit(0,"cm"), 
        strip.text.x = element_blank()) +
  xlab("Colonies") +
  ylab("K=2") +
  scale_fill_manual(values = colorcodesk2)

p3 <- ggplot(data=K3_mat_melt, aes(y = K3_mat_melt$value, x = K3_mat_melt$Sample, fill = K3_mat_melt$variable, facets = K3_mat_melt$Colony)) + 
  geom_bar(position="fill", stat="identity", colour=NA, size=0, width = 1) +
  scale_x_discrete(breaks = NULL, labels = NULL) +
  scale_y_continuous(limits = c(0,1), expand = c(0, 0), sec.axis = dup_axis()) +
  facet_grid(.~Colony, space="free_x", scales="free_x", switch="x") + 
  theme_bw() +
  theme(panel.background = element_blank(),panel.grid.major = element_blank(),
        panel.grid.minor = element_blank(), panel.border = element_rect(color = "black", size = 0.5),
        panel.spacing.x = unit(0.15, "lines"),
        axis.text.x=element_blank(),
        axis.text.y.left =element_text(colour="black"),
        axis.title.y.left =element_blank(),
        axis.line = element_line(colour = "black"),
        plot.title = element_text(hjust = 0.5, size=16, face="bold"), 
        axis.title.x = element_blank(),
        axis.text.y.right =element_blank(),
        axis.title.y.right = element_text(size=12, face="bold", angle = 0, vjust = 0.5),
        axis.ticks.y.right =element_blank(),
        legend.position = "none",
        strip.placement = "outside", strip.background = element_rect(fill=NA,colour=NA), panel.spacing=unit(0,"cm"),
        strip.text.x = element_blank()) +
  xlab("Colonies") +
  ylab("K=3") +
  scale_fill_manual(values = colorcodesk3)

p4 <- ggplot(data=K4_mat_melt, aes(y = K4_mat_melt$value, x = K4_mat_melt$Sample, fill = K4_mat_melt$variable, facets = K4_mat_melt$Colony)) + 
  geom_bar(position="fill", stat="identity", colour=NA, size=0, width = 1) +
  scale_x_discrete(breaks = NULL, labels = NULL) +
  scale_y_continuous(limits = c(0,1), expand = c(0, 0), sec.axis = dup_axis()) +
  facet_grid(.~Colony, space="free_x", scales="free_x", switch="x") + 
  theme_bw() +
  theme(panel.background = element_blank(),panel.grid.major = element_blank(),
        panel.grid.minor = element_blank(), panel.border = element_rect(color = "black", size = 0.5),
        panel.spacing.x = unit(0.15, "lines"),
        axis.text.x=element_text(colour="black"),
        axis.text.y.left =element_text(colour="black"),
        axis.title.y.left =element_blank(),
        axis.line = element_line(colour = "black"),
        plot.title = element_text(hjust = 0.5, size=16, face="bold"), 
        axis.title.x = element_text(size=12, face="bold"),
        axis.text.y.right =element_blank(),
        axis.title.y.right = element_text(size=12, face="bold", angle = 0, vjust = 0.5),
        axis.ticks.y.right =element_blank(),
        legend.position = "none",
        strip.placement = "outside", strip.background = element_rect(fill=NA,colour=NA), panel.spacing=unit(0,"cm")) +
  xlab("Colonies") +
  ylab("K=4") +
  scale_fill_manual(values = colorcodesk4)

pdf("Puffin_K2-4_Admixture.pdf", 10.3, 6.2)
ggarrange(p2, p3, p4, ncol = 1, nrow = 3, heights = c(1,1,1.15)) #bottom needs more space because of legend
dev.off()

```

Do Admixture with Substructure

```bash
mkdir Substructure
cd Substructure

# NgsAdmix for K from 2 to 10
for K in $(seq 1 10) ;
do echo ${K};
for i in $(seq 1 50) ;
do sbatch NgsAdmix.sh ${K} ${i};
done ;
done ;


```

-> NgsAdmix.sh

```bash
#!/bin/bash

#making a random seed
R=$(echo $RANDOM % 100 | bc)
S=$(bc <<<"scale=0; ${R} * ${1} * ${2}")


module load NGSadmix/32-GCC-7.3.0-2.30

Threads=16

NGSadmix -likes ModernPuffinAngsd_NoZ_NoUnpl.beagle.ldpruned.edit.subset1.gz -K ${1} -P ${Threads} -o ModernPuffinAngsd_NoZ_NoUnpl.beagle.ldpruned.edit.subset1_ngsAdmix_k${1}_n${2} -maxiter 5000 -seed ${S}

```

Then repeat CLUMPAK and plotting
