# Treemix  with Outgroup (RAZ)


```bash


zcat ModernPuffinAngsd_NoZ_NoUnpl.beagle.ldpruned.gz | tail -n+2 | cut -f 1 | awk -F '_' '{print $1"_"$2"_"$3"\t"$4}' > sites2do
wc -l sites2do

cp /cluster/work/users/oliverke/ANGSD_Modern//ChromosomeList .
grep -v "Z" ChromosomeList | grep -v "unplaced" > ChromosomeList.edit


sbatch Outgroup_ANGSD_IBS.sh

```

-> Outgroup_ANGSD_IBS.sh

```bash
#!/bin/bash

FILTERS="-uniqueOnly 1 -remove_bads 1 -minMapQ 30 -minQ 30 -C 50 -baq 2 -checkBamHeaders 1 -doHWE 1 -skipTriallelic 1"
TODO="-doMajorMinor 1 -doMaf 1 -doCounts 1 -doIBS 2"

Chromosome=$(cat ChromosomeList.edit | awk -F ':' '{print $1}' | grep -w Scaffolds_chromosome_${SLURM_ARRAY_TASK_ID} )
ChromosomeEdit=$(echo ${Chromosome}":")
grep -w Scaffolds_chromosome_${SLURM_ARRAY_TASK_ID} sites2do > sites_Chromosome${SLURM_ARRAY_TASK_ID}_2do


module load angsd/0.931-GCC-8.2.0-2.31.1

sleep 120

angsd sites index sites_Chromosome${SLURM_ARRAY_TASK_ID}_2do

sleep 120 

angsd -b bams_good.edit -GL 1 $FILTERS $TODO -ref Assembly_Puffin_NU.MT.fasta -r ${ChromosomeEdit} -sites sites_Chromosome${SLURM_ARRAY_TASK_ID}_2do -out OutgroupAngsd_IBS_Chromosome${SLURM_ARRAY_TASK_ID}


```

###Samples###
Run 100 replicates (different seed) → best likelihood as tree
Run 100 bootstraps of that tree (different seed) → bootstrap support

###Pops###
Run 100 replicates (different seed) for each migration → best likelihood to display as tree and SE
check how likelihood and variation explained change → graph m vs like or m vs. var expl.
Choose best likelihood tree for best m and do 100 bootstrap  

```bash
#No Z or unplaced
zcat OutgroupAngsd_IBS_Chromosome1.ibs.gz > OutgroupAngsd_IBS_NoZ_NoUn.ibs 
for i in 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 2 3 4 5 6 7 8 9 ;
do zcat OutgroupAngsd_IBS_Chromosome${i}.ibs.gz | tail -n +2 >> OutgroupAngsd_IBS_NoZ_NoUn.ibs ;
done ;
gzip OutgroupAngsd_IBS_NoZ_NoUn.ibs
zcat OutgroupAngsd_IBS_NoZ_NoUn.ibs.gz | tail -n +2 | wc -l

cat bams_good.edit| awk -F '/' '{print $6}' | awk -F '.' '{print $1}' > samples
cat samples | awk -F '0' '{print $1}' | sort | uniq > pops


### NEED TO TRANSFORM ANGSD FORMAT TO TREEMIX FORMAT

#Samples
Samples=$(cat samples | tr "\n" " ")
echo -e chr" "pos" "major" "minor" "${Samples} > header
zcat OutgroupAngsd_IBS_NoZ_NoUn.ibs.gz | tail -n+2 | cat header - > OutgroupAngsd_IBS_NoZ_NoUn.edit.ibs
rm header
cat samples | while read i ;
do echo ${i} ;
ColumnNo=$(head -1 OutgroupAngsd_IBS_NoZ_NoUn.edit.ibs | tr " " "\n" | grep -w -n ${i} | awk -F ':' '{print $1}') ;
awk -v c1=$ColumnNo -F ' ' '{print $c1}' OutgroupAngsd_IBS_NoZ_NoUn.edit.ibs | tail -n+2 | sed 's/0/A/g ; s/-1/B/g ; s/1/C/g; s/A/1,0/g ; s/B/0,0/g ; s/C/0,1/g' > ${i}.column ;
echo ${i} | cat - ${i}.column > ${i}.column.edit ;
rm ${i}.column ;
done
paste -d " " *.column.edit > ModernPuffinAngsd_NoZ_NoUnpl.IBS.ldpruned.withOut.treemix.samples ;
rm *.column.edit
rm OutgroupAngsd_IBS_NoZ_NoUn.edit.ibs
gzip ModernPuffinAngsd_NoZ_NoUnpl.IBS.ldpruned.withOut.treemix.samples

#Pops
cat pops | while read line ;
do echo ${line} ;
touch pop_refallele ;
touch pop_altallele ;
grep ${line} samples > samples.pop ;
cat samples.pop | while read i ;
do echo ${i} ;
ColumnNo=$(zcat ModernPuffinAngsd_NoZ_NoUnpl.IBS.ldpruned.withOut.treemix.samples.gz | head -1 | tr " " "\n" | grep -w -n ${i} | awk -F ':' '{print $1}') ;
zcat ModernPuffinAngsd_NoZ_NoUnpl.IBS.ldpruned.withOut.treemix.samples.gz | awk -v c1=$ColumnNo -F ' ' '{print $c1}' | tail -n +2 | awk -F ',' '{print $1}' > refallele${i} ;
zcat ModernPuffinAngsd_NoZ_NoUnpl.IBS.ldpruned.withOut.treemix.samples.gz | awk -v c1=$ColumnNo -F ' ' '{print $c1}' | tail -n +2 | awk -F ',' '{print $2}' > altallele${i} ;
done ;
paste refallele* >> pop_refallele ;
paste altallele* >> pop_altallele ;
awk '{for(i=1;i<=NF;i++) t+=$i; print t; t=0}' pop_refallele > refallele_sum ;
awk '{for(i=1;i<=NF;i++) t+=$i; print t; t=0}' pop_altallele > altallele_sum ;
paste -d "," refallele_sum altallele_sum > popsum ;
echo ${line} | cat - popsum > ModernPuffinAngsd_NoZ_NoUnpl.IBS.ldpruned.withOut.treemix_${line} ;
rm refallele* ;
rm altallele* ;
rm samples.pop ;
rm pop_refallele ;
rm pop_altallele ;
rm popsum ;
done ;

paste -d " " ModernPuffinAngsd_NoZ_NoUnpl.IBS.ldpruned.withOut.treemix_* >> ModernPuffinAngsd_NoZ_NoUnpl.IBS.ldpruned.withOut.treemix.pops

rm ModernPuffinAngsd_NoZ_NoUnpl.IBS.ldpruned.withOut.treemix_*
gzip ModernPuffinAngsd_NoZ_NoUnpl.IBS.ldpruned.withOut.treemix.pops

#Change uncovered RAZ positions to random ref or alt allele
#samples
gunzip ModernPuffinAngsd_NoZ_NoUnpl.IBS.ldpruned.withOut.treemix.samples.gz
ColumnNo=$(head -1 ModernPuffinAngsd_NoZ_NoUnpl.IBS.ldpruned.withOut.treemix.samples | tr " " "\n" | grep -w -n "RAZ" | awk -F ':' '{print $1}') ;
awk -v c1=$ColumnNo -F ' ' '{print $c1}' ModernPuffinAngsd_NoZ_NoUnpl.IBS.ldpruned.withOut.treemix.samples |awk '{$0=gensub(/0,0/, 2+int(rand()*10000), "g", $0)}1' | awk '($1 <5002 && $1 >1) {print "1,0"; next}1' | awk '($1 >5001 && $1 <10002 ) {print "0,1"; next}1' > RAZ.column ; 
cut -d ' ' -f 1-53,55-72 ModernPuffinAngsd_NoZ_NoUnpl.IBS.ldpruned.withOut.treemix.samples | paste -d ' ' - RAZ.column > ModernPuffinAngsd_NoZ_NoUnpl.IBS.ldpruned.withOut.treemix.samples.edit
rm RAZ.column ;
gzip ModernPuffinAngsd_NoZ_NoUnpl.IBS.ldpruned.withOut.treemix.samples.edit
gzip ModernPuffinAngsd_NoZ_NoUnpl.IBS.ldpruned.withOut.treemix.samples

#pops
gunzip ModernPuffinAngsd_NoZ_NoUnpl.IBS.ldpruned.withOut.treemix.pops.gz
ColumnNo=$(head -1 ModernPuffinAngsd_NoZ_NoUnpl.IBS.ldpruned.withOut.treemix.pops | tr " " "\n" | grep -w -n "RAZ" | awk -F ':' '{print $1}') ;
awk -v c1=$ColumnNo -F ' ' '{print $c1}' ModernPuffinAngsd_NoZ_NoUnpl.IBS.ldpruned.withOut.treemix.pops |awk '{$0=gensub(/0,0/, 2+int(rand()*10000), "g", $0)}1' | awk '($1 <5002 && $1 >1) {print "1,0"; next}1' | awk '($1 >5001 && $1 <10002 ) {print "0,1"; next}1' > RAZ.column ; 
cut -d ' ' -f 1-9,11-13 ModernPuffinAngsd_NoZ_NoUnpl.IBS.ldpruned.withOut.treemix.pops | paste -d ' ' - RAZ.column > ModernPuffinAngsd_NoZ_NoUnpl.IBS.ldpruned.withOut.treemix.pops.edit
rm RAZ.column ;
gzip ModernPuffinAngsd_NoZ_NoUnpl.IBS.ldpruned.withOut.treemix.pops.edit
gzip ModernPuffinAngsd_NoZ_NoUnpl.IBS.ldpruned.withOut.treemix.pops


### Run Treemix


for N in $(seq 1 100) ;
do echo ${N};
sbatch Treemix_Sample_Like.sh ${N};
done ;


for N in $(seq 0 10) ;
do echo ${N};
for M in {1..100} ;
do echo ${M} ;
sbatch Treemix_Pop_Mig_Like.sh ${N} ${M};
done ;
done ;

```

-> Treemix_Sample_Like.sh 

```bash
#!/bin/bash

module load TreeMix/1.13-intel-2018b

#making a random seed
R1=$(echo $RANDOM % 100 | bc)
R2=$(echo $RANDOM % 100 | bc)
S=$(bc <<<"scale=0; ${R1} * ${R2} * ${1}")

## Run treemix
treemix -i ModernPuffinAngsd_NoZ_NoUnpl.IBS.ldpruned.withOut.treemix.samples.edit.gz -global -noss -root RAZ -o ModernPuffinAngsd_NoZ_NoUnpl.IBS.ldpruned.withOut.treemix.samples.m0.${1} -seed ${S}


```

-> Treemix_Pop_Mig_Like.sh

```bash
#!/bin/bash

module load TreeMix/1.13-intel-2018b

#making a random seed
R1=$(echo $RANDOM % 100 | bc)
R2=$(echo $RANDOM % 100 | bc)
S=$(bc <<<"scale=0; ${R1} * ${R2} * ${1}")

## Run treemix
treemix -i ModernPuffinAngsd_NoZ_NoUnpl.IBS.ldpruned.withOut.treemix.pops.edit.gz -m ${1} -global -root RAZ -o ModernPuffinAngsd_NoZ_NoUnpl.IBS.ldpruned.withOut.treemix.pops.${2}.m${1} -seed ${S}


```

Check highest likelihood tree for sample and each m for pop
```bash

#samples 
cd sample_like_boot
Like=$(cat ModernPuffinAngsd_NoZ_NoUnpl.IBS.ldpruned.withOut.treemix.samples.m0.*.llik | awk -F ':' '{print $2}' | sed 's/ //g' | sort -r -n | uniq | head -1) 
Replicate=$(grep -l -w ${Like} ModernPuffinAngsd_NoZ_NoUnpl.IBS.ldpruned.withOut.treemix.samples.m0.*.llik | head -1 | awk -F '.' '{print $8}')
mv ModernPuffinAngsd_NoZ_NoUnpl.IBS.ldpruned.withOut.treemix.samples.m0.${Replicate}.* ../
cd ..
rm sample_like_boot/*
mv ModernPuffinAngsd_NoZ_NoUnpl.IBS.ldpruned.withOut.treemix.samples.m0.${Replicate}.* sample_like_boot/
cd sample_like_boot/
zcat ModernPuffinAngsd_NoZ_NoUnpl.IBS.ldpruned.withOut.treemix.samples.m0.${Replicate}.treeout.gz | head -1 > ModernPuffinAngsd_NoZ_NoUnpl.IBS.ldpruned.withOut.treemix.samples.m0.main_tree ;

#pops
cd pop_like_boot
for N in $(seq 1 10) ;
do echo ${N};
Like=$(cat ModernPuffinAngsd_NoZ_NoUnpl.IBS.ldpruned.withOut.treemix.pops.*.m${N}.llik | awk -F ':' '{print $2}' | sed 's/ //g' | sort -r -n | uniq | head -1) ;
Replicate=$(grep -l -w ${Like} ModernPuffinAngsd_NoZ_NoUnpl.IBS.ldpruned.withOut.treemix.pops.*.m${N}.llik | head -1 | awk -F '.' '{print $7}') ;
mv ModernPuffinAngsd_NoZ_NoUnpl.IBS.ldpruned.withOut.treemix.pops.${Replicate}.m${N}.* ../ ;
cd .. ;
rm pop_like_boot/ModernPuffinAngsd_NoZ_NoUnpl.IBS.ldpruned.withOut.treemix.pops.*.m${N}.* ;
mv ModernPuffinAngsd_NoZ_NoUnpl.IBS.ldpruned.withOut.treemix.pops.${Replicate}.m${N}.* pop_like_boot/ ;
cd pop_like_boot/ ;
zcat ModernPuffinAngsd_NoZ_NoUnpl.IBS.ldpruned.withOut.treemix.pops.${Replicate}.m${N}.treeout.gz | head -1 > ModernPuffinAngsd_NoZ_NoUnpl.IBS.ldpruned.withOut.treemix.pops.m${N}.main_tree ;
done

for N in {0..10} ;
do echo ${N} ;
for i in vertices.gz treeout.gz modelcov.gz llik edges.gz covse.gz cov.gz ;
do mv ModernPuffinAngsd_NoZ_NoUnpl.IBS.ldpruned.withOut.treemix.pops.*.m${N}.${i} ModernPuffinAngsd_NoZ_NoUnpl.IBS.ldpruned.withOut.treemix.pops.m${N}.${i} ;
done ;
done ; 

#use R with script plotting_funcs.R (Treemix script)
```

Investigate best M for pop
-> Plot.Variation

```bash
library(ggplot2)
library(SiZer)
library(OptM)

##OptM###
Puffin_Evanno = optM("pop_like_boot/", method = "Evanno")
plot_optM(Puffin_Evanno, method = "Evanno")

Puffin_Linear = optM("pop_like_boot/", method = "linear")
plot_optM(Puffin_Linear, method = "linear")

Puffin_SiZer = optM("pop_like_boot/", method = "SiZer")
plot_optM(Puffin_SiZer, method = "SiZer")

plot_optM(Puffin_Evanno, method = "Evanno", pdf = "BestM_Evanno.pdf")
plot_optM(Puffin_Linear, method = "linear", pdf = "BestM_Linear.pdf")

```

Bootstrap best sample and best pop (best m and likelihood) tree

```bash

for N in $(seq 1 100) ;
do echo ${N};
sbatch Treemix_Sample_Boot.sh ${N};
done ;

for m in 0 1 ;
do echo $m
for N in $(seq 1 100) ;
do echo ${N};
sbatch Treemix_Pop_Boot.sh ${N} ${m};
done ;
done ;

```

-> Treemix_Sample_Boot.sh

```bash
#!/bin/bash

module load TreeMix/1.13-intel-2018b

#making a random seed
R1=$(echo $RANDOM % 100 | bc)
R2=$(echo $RANDOM % 100 | bc)
S=$(bc <<<"scale=0; ${R1} * ${R2} * ${1}")

## Run treemix
treemix -i ModernPuffinAngsd_NoZ_NoUnpl.IBS.ldpruned.withOut.treemix.edit.samples.gz -global -noss -k 500 -root RAZ -bootstrap -o ModernPuffinAngsd_NoZ_NoUnpl.IBS.ldpruned.withOut.treemix.samples.m0.boot.${1} -seed ${S}

```

-> Treemix_Pop_Boot.sh

```bash
#!/bin/bash

module load TreeMix/1.13-intel-2018b

#making a random seed
R1=$(echo $RANDOM % 100 | bc)
R2=$(echo $RANDOM % 100 | bc)
S=$(bc <<<"scale=0; ${R1} * ${R2} * ${1}")

## Run treemix
treemix -i ModernPuffinAngsd_NoZ_NoUnpl.IBS.ldpruned.withOut.treemix.pops.edit.gz -m ${2} -global -k 500 -root RAZ -bootstrap -o ModernPuffinAngsd_NoZ_NoUnpl.IBS.ldpruned.withOut.treemix.pops.boot.${1}.m${2} -seed ${S}


```

Add Bootstrap to trees

```bash

#pops
for i in 0 1 ;
do touch ModernPuffinAngsd_NoZ_NoUnpl.IBS.ldpruned.withOut.treemix.pops.m${i}.boot_tree ;
for N in {1..100} ;
do zcat ModernPuffinAngsd_NoZ_NoUnpl.IBS.ldpruned.withOut.treemix.pops.boot.${N}.m${i}.treeout.gz | head -1  >> ModernPuffinAngsd_NoZ_NoUnpl.IBS.ldpruned.withOut.treemix.pops.m${i}.boot_tree ;
done ;
rm *boot*m${i}.*.gz ;
rm *boot*m${i}.llik ;
module purge ;
module load IQ-TREE/1.6.12-foss-2018b ;
iqtree -o RAZ -sup ModernPuffinAngsd_NoZ_NoUnpl.IBS.ldpruned.withOut.treemix.pops.m${i}.main_tree ModernPuffinAngsd_NoZ_NoUnpl.IBS.ldpruned.withOut.treemix.pops.m${i}.boot_tree ;
done ;

#samples
touch ModernPuffinAngsd_NoZ_NoUnpl.IBS.ldpruned.withOut.treemix.samples.m0.boot_tree ;
for N in {1..100} ;
do zcat ModernPuffinAngsd_NoZ_NoUnpl.IBS.ldpruned.withOut.treemix.samples.m0.boot.${N}.treeout.gz | head -1  >> ModernPuffinAngsd_NoZ_NoUnpl.IBS.ldpruned.withOut.treemix.samples.m0.boot_tree ;
done ;
rm *boot*.gz
rm *boot*.llik
module purge ;
module load IQ-TREE/1.6.12-foss-2018b ;
iqtree -o RAZ -sup ModernPuffinAngsd_NoZ_NoUnpl.IBS.ldpruned.withOut.treemix.samples.m0.main_tree ModernPuffinAngsd_NoZ_NoUnpl.IBS.ldpruned.withOut.treemix.samples.m0.boot_tree ;


#These trees can be plotted now!!
```


F3 stats

```bash
sbatch Treemix_Pop_F3.sh

```

-> Treemix_Pop_F3.sh

```bash
#!/bin/bash

module load TreeMix/1.13-intel-2018b

## Run treemix
threepop -i ModernPuffinAngsd_NoZ_NoUnpl.IBS.ldpruned.withOut.treemix.pops.edit.gz -k 500 > ModernPuffinAngsd_NoZ_NoUnpl.IBS.ldpruned.withOut.treemix.pops.F3stat

```

